@@ -14,6 +14,7 @@ from pylons import app_globals as g
 from tg import (
         config,
         expose,
+        flash,
         redirect,
         validate,
         )
@@ -23,10 +24,13 @@ from tg.decorators import (
         )
 
 from allura.controllers import BaseController
-from allura.lib.decorators import require_post
+from allura.lib.decorators import require_post, task
 from allura.model import ApiTicket
 
-from forgeimporters.base import ToolImporter
+from forgeimporters.base import (
+        ToolImporter,
+        ToolImportForm,
+        )
 
 from forgewiki.scripts.wiki_from_trac.extractors import WikiExporter
 from forgewiki.scripts.wiki_from_trac.loaders import load_data
@@ -34,35 +38,49 @@ from forgewiki.scripts.wiki_from_trac.wiki_from_trac import WikiFromTrac
 from forgewiki.wiki_main import ForgeWikiApp
 
 
-class TracWikiImportSchema(fe.Schema):
+@task(notifications_disabled=True)
+def import_tool(**kw):
+    TracWikiImporter().import_tool(c.project, c.user, **kw)
+
+
+class TracWikiImportForm(ToolImportForm):
     trac_url = fev.URL(not_empty=True)
-    mount_point = fev.UnicodeString()
-    mount_label = fev.UnicodeString()
 
 
 class TracWikiImportController(BaseController):
+    def __init__(self):
+        self.importer = TracWikiImporter()
+
+    @property
+    def target_app(self):
+        return self.importer.target_app
+
     @with_trailing_slash
     @expose('jinja:tracwikiimporter:templates/index.html')
     def index(self, **kw):
-        return {}
+        return dict(importer=self.importer,
+                target_app=self.target_app)
 
     @without_trailing_slash
     @expose()
     @require_post()
-    @validate(TracWikiImportSchema(), error_handler=index)
+    @validate(TracWikiImportForm(ForgeWikiApp), error_handler=index)
     def create(self, trac_url, mount_point, mount_label, **kw):
-        app = TracWikiImporter().import_tool(c.project, c.user,
+        import_tool.post(
                 mount_point=mount_point,
                 mount_label=mount_label,
-                trac_url=trac_url)
-        redirect(app.url())
+                trac_url=trac_url,
+                )
+        flash('Wiki import has begun. Your new wiki will be available '
+                'when the import is complete.')
+        redirect(c.project.url() + 'admin/')
 
 
 class TracWikiImporter(ToolImporter):
     target_app = ForgeWikiApp
     source = 'Trac'
     controller = TracWikiImportController
-    tool_label = 'Wiki'
+    tool_label = 'Trac Wiki Importer'
     tool_description = 'Import your wiki from Trac.  Note: wiki content is imported, but not revision history or attachments.'
 
     def import_tool(self, project, user, project_name=None, mount_point=None,
